pub fn nfa(input: &str) -> Result<ParsedNfa<'_>, Error<&str>>Expand description
Parses a NFA according to the format above. The whole string must be parsable, otherwise this function errors. Note that the result is a ParsedNfa, which is not guaranteed to be a valid crate::nfa::Nfa. Use TryInto::try_into to convert a ParsedNfa to a crate::nfa::Nfa.